@@ -1,10 +1,12 @@
+//! To run this code, clone the rusty_engine repository and run the command:
+//!
+//!     cargo run --release --example music
+
 //! This is an example of playing a music preset. For playing your own music file, please see the
 //! `sound` example.
 
 use rusty_engine::prelude::*;
 
-rusty_engine::init!();
-
 fn main() {
     let mut game = Game::new();
     let msg = game.add_text(
