@@ -1,11 +1,13 @@
+//! To run this code, clone the rusty_engine repository and run the command:
+//!
+//!     cargo run --release --example music_sampler
+
 use rusty_engine::prelude::*;
 
 struct GameState {
     music_index: usize,
 }
 
-rusty_engine::init!(GameState);
-
 fn main() {
     let mut game = Game::new();
     let msg = game.add_text(
