@@ -1,3 +1,7 @@
+//! To run this code, clone the rusty_engine repository and run the command:
+//!
+//!     cargo run --release --example extreme_drivers_ed
+
 use rusty_engine::prelude::*;
 
 struct GameState {
@@ -8,8 +12,6 @@ struct GameState {
     velocity: Vec2,
 }
 
-rusty_engine::init!(GameState);
-
 fn main() {
     let mut game = Game::new();
 
