@@ -1,10 +1,12 @@
+//! To run this code, clone the rusty_engine repository and run the command:
+//!
+//!     cargo run --release --example sfx
+
 //! This is an example of playing a sound effect preset. For playing your own sound effect file,
 //! please see the `sound` example.
 
 use rusty_engine::prelude::*;
 
-rusty_engine::init!();
-
 fn main() {
     let mut game = Game::new();
     let msg = game.add_text(
