@@ -1,15 +1,17 @@
+//! To run this code, clone the rusty_engine repository and run the command:
+//!
+//!     cargo run --release --example sound
+
 //! This is an example of playing sound by path. For playing music or sound effect presets, please
 //! see the `music` or `sfx` examples.
 
 use rusty_engine::prelude::*;
 
-rusty_engine::init!();
-
 fn main() {
     let mut game = Game::new();
     let msg = game.add_text(
         "msg",
-        "You can add your own sound files to the assets/audio directory (or its\nsubdirectories) and play them by relative path. For example:",
+        "You can add your own sound files to the assets/audio directory\n(or its subdirectories) and play them by relative path. This\nworks for both sound effects and music. For example:",
     );
     msg.translation.y = 100.0;
 
