@@ -1,9 +1,12 @@
-use rusty_engine::prelude::*;
+//! To run this code, clone the rusty_engine repository and run the command:
+//!
+//!     cargo run --release --example window
 
-rusty_engine::init!();
+use rusty_engine::prelude::*;
 
 fn main() {
     let mut game = Game::new();
+
     game.window_settings(WindowDescriptor {
         width: 800.0,
         height: 200.0,
