@@ -1,22 +1,37 @@
-use bevy::prelude::{
-    info, AssetServer, Assets, Color, ColorMaterial, Commands, HorizontalAlign, Query, Res, ResMut,
-    SpriteBundle, Text as BevyText, Text2dBundle, TextAlignment, TextStyle, Vec2, VerticalAlign,
-    Windows,
+use bevy::{
+    app::AppExit,
+    core::Time,
+    input::system::exit_on_esc_system,
+    prelude::{
+        info, App, AssetServer, Color, Commands, Component, DefaultPlugins, Entity, EventReader,
+        EventWriter, HorizontalAlign, OrthographicCameraBundle, ParallelSystemDescriptorCoercion,
+        QuerySet, QueryState, Res, ResMut, SpriteBundle, Text as BevyText, Text2dBundle,
+        TextAlignment, TextStyle, Transform, Vec2, VerticalAlign, Windows,
+    },
+    utils::HashMap,
+};
+use bevy_kira_audio::*;
+use bevy_prototype_lyon::prelude::*;
+use std::{
+    ops::{Deref, DerefMut},
+    path::PathBuf,
+    time::Duration,
 };
-use bevy::utils::HashMap;
-pub use bevy::window::{WindowDescriptor, WindowMode, WindowResizeConstraints};
-use bevy_prototype_debug_lines::*;
-use std::path::PathBuf;
-use std::time::Duration;
 
 use crate::{
     audio::AudioManager,
-    mouse::{CursorMoved, MouseButtonInput, MouseMotion, MouseWheel},
-    prelude::{CollisionEvent, KeyboardInput, KeyboardState, MouseState},
+    mouse::{CursorMoved, MouseButtonInput, MouseMotion, MousePlugin, MouseWheel},
+    prelude::{
+        AudioManagerPlugin, CollisionEvent, KeyboardInput, KeyboardPlugin, KeyboardState,
+        MouseState, PhysicsPlugin,
+    },
     sprite::Sprite,
     text::Text,
 };
 
+// Public re-export
+pub use bevy::window::{WindowDescriptor, WindowMode, WindowResizeConstraints};
+
 /// EngineState is the primary way that you will interact with Rusty Engine. Every frame this struct
 /// is provided to the "logic" function (or closure) that you provided to [`Game::run`]. The
 /// fields in this struct are divided into two groups:
@@ -44,7 +59,9 @@ pub struct EngineState {
     /// SYNCED - If set to `true`, the game exits. Note: the current frame will run to completion first.
     pub should_exit: bool,
     /// SYNCED - If set to `true`, then debug lines are shown depicting sprite colliders
-    pub debug_sprite_colliders: bool,
+    pub show_colliders: bool,
+    // so we can tell if the value changed this frame
+    last_show_colliders: bool,
     /// INFO - All the collision events that occurred this frame. For collisions to be generated
     /// between sprites, both sprites must have [`Sprite.collision`] set to `true`. Collision events
     /// are generated when two sprites' colliders begin or end overlapping in 2D space.
@@ -137,26 +154,50 @@ impl EngineState {
 pub fn setup(
     mut commands: Commands,
     asset_server: Res<AssetServer>,
-    materials: ResMut<Assets<ColorMaterial>>,
     mut engine_state: ResMut<EngineState>,
 ) {
-    add_sprites(&mut commands, &asset_server, materials, &mut engine_state);
+    add_sprites(&mut commands, &asset_server, &mut engine_state);
     add_texts(&mut commands, &asset_server, &mut engine_state);
 }
 
+fn add_collider_lines(commands: &mut Commands, sprite: &mut Sprite) {
+    // Add the collider lines, a visual representation of the sprite's collider
+    let points = sprite.collider.points(); // will be empty vector if NoCollider
+    if points.len() >= 2 {
+        let mut path_builder = PathBuilder::new();
+        path_builder.move_to(points[0]);
+        for point in &points[1..] {
+            path_builder.line_to(*point);
+        }
+        path_builder.close(); // draws the line from the last point to the first point
+        let line = path_builder.build();
+        let transform = sprite.bevy_transform();
+        commands
+            .spawn_bundle(GeometryBuilder::build_as(
+                &line.0, // can be changed to `&line` once bevy_prototype_lyon > 0.4 is released
+                DrawMode::Stroke(StrokeMode::new(Color::WHITE, 1.0 / transform.scale.x)),
+                transform,
+            ))
+            .insert(ColliderLines {
+                sprite_label: sprite.label.clone(),
+            });
+    }
+    sprite.collider_dirty = false;
+}
+
 // helper function: Add Bevy components for all the sprites in engine_state.sprites
 #[doc(hidden)]
 pub fn add_sprites(
     commands: &mut Commands,
     asset_server: &Res<AssetServer>,
-    mut materials: ResMut<Assets<ColorMaterial>>,
     engine_state: &mut EngineState,
 ) {
     for (_, sprite) in engine_state.sprites.drain() {
+        // Create the sprite
         let transform = sprite.bevy_transform();
-        let texture_handle = asset_server.load(PathBuf::from("sprite").join(&sprite.filepath));
+        let texture_path = PathBuf::from("sprite").join(&sprite.filepath);
         commands.spawn().insert(sprite).insert_bundle(SpriteBundle {
-            material: materials.add(texture_handle.into()),
+            texture: asset_server.load(texture_path),
             transform,
             ..Default::default()
         });
@@ -207,30 +248,11 @@ pub fn update_window_dimensions(windows: Res<Windows>, mut engine_state: ResMut<
     }
 }
 
-// system - draw sprite colliders
+// Component to add to the collider lines visualizations to link them to the sprite they represent
+#[derive(Component)]
 #[doc(hidden)]
-pub fn draw_sprite_colliders(
-    engine_state: Res<EngineState>,
-    mut lines: ResMut<DebugLines>,
-    sprite_query: Query<&Sprite>,
-) {
-    if !engine_state.debug_sprite_colliders {
-        return;
-    }
-    for sprite in sprite_query.iter() {
-        let points = sprite.collider.relative_to(sprite); // will be empty vector if NoCollider
-        let length = points.len();
-        if length < 2 {
-            continue;
-        }
-        let mut curr = 0;
-        let mut next = 1;
-        while curr < length {
-            lines.line(points[curr].extend(0.0), points[next].extend(0.0), 0.0);
-            curr += 1;
-            next = (next + 1) % length;
-        }
-    }
+pub struct ColliderLines {
+    sprite_label: String,
 }
 
 /// A [`Game`] represents the entire game and its data.
@@ -240,104 +262,17 @@ pub fn draw_sprite_colliders(
 ///
 /// [`Game`] forwards method calls to [`EngineState`] when it can, so you should be able to use all
 /// of the methods in [`EngineState`] on [`Game`] during your game setup in your `main()` function.
-///
-/// *Note:* YOU NEED TO USE THE VERSION OF `Game` GENERATED BY THE `rusty_engine::init!( ... )`
-/// MACRO CALL!  _This_ version is a dummy just so we can document how to use the generated version!
-pub struct Game {}
-
-impl Game {
-    /// Create an empty [`Game`] with an empty [`EngineState`]
-    ///
-    /// *Note:* YOU NEED TO USE THE VERSION OF `Game` GENERATED BY THE `rusty_engine::init!( ... )`
-    /// MACRO CALL!  _This_ version is a dummy just so we can document how to use the generated version!
-    #[allow(clippy::new_without_default)]
-    pub fn new() -> Self {
-        panic!("Use the `Game` struct generated by rusty_engine::init!( ... ). See https://github.com/CleanCut/rusty_engine/#quick-start")
-    }
-
-    /// Use this to set properties of the native OS window before running the game. See the
-    /// [window](https://github.com/CleanCut/rusty_engine/blob/main/examples/window.rs) example for
-    /// more information.
-    ///
-    /// *Note:* YOU NEED TO USE THE VERSION OF `Game` GENERATED BY THE `rusty_engine::init!( ... )`
-    /// MACRO CALL!  _This_ version is a dummy just so we can document how to use the generated version!
-    #[allow(unused_variables)]
-    pub fn window_settings(&mut self, window_descriptor: WindowDescriptor) -> &mut Self {
-        panic!("Use the `Game` struct generated by rusty_engine::init!( ... ). See https://github.com/CleanCut/rusty_engine/#quick-start")
-    }
-
-    /// Start the game.
-    ///
-    /// # Examples
-    ///
-    /// There are much more interesting and complete examples in [the `examples/` directory.](https://github.com/CleanCut/rusty_engine/tree/main/examples)
-    ///
-    /// The type of `initial_game_state` is the type you pass into `rusty_engine::init!()`, or a unit struct `()` if you don't pass anything in.
-    #[allow(unused_variables)]
-    pub fn run(&mut self, initial_game_state: ()) {
-        panic!("Use the `Game` struct generated by rusty_engine::init!( ... ). See https://github.com/CleanCut/rusty_engine/#quick-start")
-    }
-
-    #[allow(unused_variables)]
-    /// `logic_function` is a function or closure that takes two parameters:
-    ///
-    /// - `engine_state: &mut EngineState`
-    /// - `game_state`, which is a mutable reference (`&mut`) to the struct type you passed to `rusty_engine::init!()`, or `&mut ()` if you don't pass anything in.
-    ///
-    /// and returns a `bool`. If `false` is returned, no more logic functions are processed this frame after this one.
-    pub fn add_logic(&mut self, logic_function: ()) {
-        panic!("Use the `Game` struct generated by rusty_engine::init!( ... ). See https://github.com/CleanCut/rusty_engine/#quick-start")
-    }
-}
-
-#[macro_export]
-macro_rules! init {
-    () => {
-        // If the user doesn't pass in a type, pass in the unit struct
-        rusty_engine::init!{()}
-    };
-    ($game_state_type:ty) => {
-
-use rusty_engine::{
-    audio::AudioManager,
-    mouse::{CursorMoved, MouseButtonInput, MouseMotion, MousePlugin, MouseWheel},
-    prelude::{
-        AudioManagerPlugin, CollisionEvent, KeyboardInput, KeyboardPlugin, KeyboardState,
-        MouseState, PhysicsPlugin,
-    },
-    game::{draw_sprite_colliders, update_window_dimensions},
-    sprite::{Sprite, SpritePreset},
-    text::Text,
-};
-use bevy::{app::AppExit, input::system::exit_on_esc_system,
-    prelude::{
-        App, AppBuilder, Assets, AssetServer, Color, ColorMaterial, Commands, DefaultPlugins,
-        Entity, EventReader, EventWriter, IntoSystem, OrthographicCameraBundle,
-        ParallelSystemDescriptorCoercion, Query, QuerySet, Res, ResMut, Text as BevyText, Transform,
-        Vec3,
-    }, utils::HashMap};
-use bevy_kira_audio::*;
-use bevy_prototype_debug_lines::*;
-use std::{sync::Mutex, time::Duration, ops::{Deref, DerefMut}};
-
-
-type LogicFunction = fn(&mut EngineState, &mut $game_state_type) -> bool;
-
-/// A [`Game`] represents the entire game and its data.
-/// By default the game will spawn an empty window, and exit upon Esc or closing of the window.
-/// Under the hood, Rusty Engine syncs the game data to Bevy to power most of the underlying
-/// functionality.
-struct Game {
-    app_builder: AppBuilder,
+pub struct Game<S: Send + Sync + 'static> {
+    app: App,
     engine_state: EngineState,
-    logic_functions: Vec<LogicFunction>,
+    logic_functions: Vec<fn(&mut EngineState, &mut S) -> bool>,
     window_descriptor: WindowDescriptor,
 }
 
-impl Default for Game {
+impl<S: Send + Sync + 'static> Default for Game<S> {
     fn default() -> Self {
         Self {
-            app_builder: App::build(),
+            app: App::new(),
             engine_state: EngineState::default(),
             logic_functions: vec![],
             window_descriptor: WindowDescriptor {
@@ -348,9 +283,9 @@ impl Default for Game {
     }
 }
 
-impl Game {
-    /// documented in the public stub
-    fn new() -> Self {
+impl<S: Send + Sync + 'static> Game<S> {
+    /// Create an empty [`Game`] with an empty [`EngineState`]
+    pub fn new() -> Self {
         if std::fs::read_dir("assets").is_err() {
             println!("FATAL: Could not find assets directory. Have you downloaded the assets?\nhttps://github.com/CleanCut/rusty_engine#you-must-download-the-assets-separately");
             std::process::exit(1);
@@ -358,73 +293,81 @@ impl Game {
         Default::default()
     }
 
-    /// documented in the public stub
-    fn window_settings(&mut self, window_descriptor: WindowDescriptor) -> &mut Self {
+    /// Use this to set properties of the native OS window before running the game. See the
+    /// [window](https://github.com/CleanCut/rusty_engine/blob/main/examples/window.rs) example for
+    /// more information.
+    pub fn window_settings(&mut self, window_descriptor: WindowDescriptor) -> &mut Self {
         self.window_descriptor = window_descriptor;
         log::debug!("window descriptor is: {:?}", self.window_descriptor);
         self
     }
 
-    /// documented in the public stub
-    fn run(&mut self, initial_game_state: $game_state_type) {
-        self.app_builder
+    /// Start the game.
+    pub fn run(&mut self, initial_game_state: S) {
+        self.app
             .insert_resource::<WindowDescriptor>(self.window_descriptor.clone())
-            .insert_resource::<$game_state_type>(initial_game_state);
-        self.app_builder
+            .insert_resource::<S>(initial_game_state);
+        self.app
             // Built-ins
             .add_plugins_with(DefaultPlugins, |group| {
                 group.disable::<bevy::audio::AudioPlugin>()
             })
-            .add_system(exit_on_esc_system.system())
+            .add_system(exit_on_esc_system)
             // External Plugins
             .add_plugin(AudioPlugin) // kira_bevy_audio
-            .add_plugin(DebugLinesPlugin) // bevy_prototype_debug_lines, for debugging sprite colliders
+            .add_plugin(ShapePlugin) // bevy_prototype_lyon, for displaying sprite colliders
             // Rusty Engine Plugins
             .add_plugin(AudioManagerPlugin)
             .add_plugin(KeyboardPlugin)
             .add_plugin(MousePlugin)
             .add_plugin(PhysicsPlugin)
             //.insert_resource(ReportExecutionOrderAmbiguities) // for debugging
-            .add_system(update_window_dimensions.system().label("update_window_dimensions").before("game_logic_sync"))
-            .add_system(game_logic_sync.system().label("game_logic_sync"))
-            .add_system(draw_sprite_colliders.system().label("draw_sprite_colliders").after("game_logic_sync"))
-            .add_startup_system(rusty_engine::game::setup.system());
-        let world = self.app_builder.world_mut();
-        world
+            .add_system(
+                update_window_dimensions
+                    .label("update_window_dimensions")
+                    .before("game_logic_sync"),
+            )
+            .add_system(game_logic_sync::<S>.label("game_logic_sync"))
+            .add_startup_system(setup);
+        self.app
+            .world
             .spawn()
             .insert_bundle(OrthographicCameraBundle::new_2d());
         let engine_state = std::mem::take(&mut self.engine_state);
-        self.app_builder.insert_resource(engine_state);
+        self.app.insert_resource(engine_state);
         let logic_functions = std::mem::take(&mut self.logic_functions);
-        self.app_builder.insert_resource(logic_functions);
-        self.app_builder.run();
+        self.app.insert_resource(logic_functions);
+        self.app.run();
     }
 
-    /// documented in the public stub
-    fn add_logic(&mut self, logic_function: LogicFunction) {
+    /// `logic_function` is a function or closure that takes two parameters:
+    ///
+    /// - `engine_state: &mut EngineState`
+    /// - `game_state`, which is a mutable reference (`&mut`) to the game state struct you defined, or `&mut ()` if you didn't define one.
+    ///
+    /// If `false` is returned, no more logic functions are processed this frame.
+    pub fn add_logic(&mut self, logic_function: fn(&mut EngineState, &mut S) -> bool) {
         self.logic_functions.push(logic_function);
     }
 }
 
 // system - the magic that connects Rusty Engine to Bevy, frame by frame
 #[allow(clippy::type_complexity, clippy::too_many_arguments)]
-fn game_logic_sync(
+fn game_logic_sync<S: Send + Sync + 'static>(
     mut commands: Commands,
     asset_server: Res<AssetServer>,
-    materials: ResMut<Assets<ColorMaterial>>,
     mut engine_state: ResMut<EngineState>,
-    mut game_state: ResMut<$game_state_type>,
-    logic_functions: Res<Vec<LogicFunction>>,
+    mut game_state: ResMut<S>,
+    logic_functions: Res<Vec<fn(&mut EngineState, &mut S) -> bool>>,
     keyboard_state: Res<KeyboardState>,
     mouse_state: Res<MouseState>,
     time: Res<Time>,
     mut app_exit_events: EventWriter<AppExit>,
     mut collision_events: EventReader<CollisionEvent>,
     mut query_set: QuerySet<(
-        Query<&Sprite>,
-        Query<&Text>,
-        Query<(Entity, &mut Sprite, &mut Transform)>,
-        Query<(Entity, &mut Text, &mut Transform, &mut BevyText)>,
+        QueryState<(Entity, &mut Sprite, &mut Transform)>,
+        QueryState<(Entity, &mut Text, &mut Transform, &mut BevyText)>,
+        QueryState<(Entity, &mut DrawMode, &mut Transform, &ColliderLines)>,
     )>,
 ) {
     // Update this frame's timing info
@@ -456,7 +399,7 @@ fn game_logic_sync(
 
     // Copy all sprites over to the engine_state to give to users
     engine_state.sprites.clear();
-    for sprite in query_set.q0().iter() {
+    for (_, sprite, _) in query_set.q0().iter() {
         let _ = engine_state
             .sprites
             .insert(sprite.label.clone(), (*sprite).clone());
@@ -464,7 +407,7 @@ fn game_logic_sync(
 
     // Copy all texts over to the engine_state to give to users
     engine_state.texts.clear();
-    for text in query_set.q1().iter() {
+    for (_, text, _, _) in query_set.q1().iter() {
         let _ = engine_state
             .texts
             .insert(text.label.clone(), (*text).clone());
@@ -478,8 +421,55 @@ fn game_logic_sync(
         }
     }
 
+    if !engine_state.last_show_colliders && engine_state.show_colliders {
+        // Just turned on show_colliders -- create collider lines for all sprites
+        for sprite in engine_state.sprites.values_mut() {
+            add_collider_lines(&mut commands, sprite);
+        }
+    } else if engine_state.last_show_colliders && !engine_state.show_colliders {
+        // Just turned off show_colliders -- delete collider lines for all sprites
+        for (entity, _, _, _) in query_set.q2().iter_mut() {
+            commands.entity(entity).despawn();
+        }
+    }
+    // Update transform & line width of all collider lines
+    if engine_state.show_colliders {
+        // Delete collider lines for sprites which are missing, or whose colliders are dirty
+        for (entity, _, _, collider_lines) in query_set.q2().iter_mut() {
+            if let Some(sprite) = engine_state.sprites.get(&collider_lines.sprite_label) {
+                if sprite.collider_dirty {
+                    commands.entity(entity).despawn();
+                }
+            } else {
+                commands.entity(entity).despawn();
+            }
+        }
+        // Add collider lines for sprites whose colliders are dirty
+        for sprite in engine_state.sprites.values_mut() {
+            if sprite.collider_dirty {
+                add_collider_lines(&mut commands, sprite);
+            }
+        }
+        // Update transform & line width
+        for (_, mut draw_mode, mut transform, collider_lines) in query_set.q2().iter_mut() {
+            if let Some(sprite) = engine_state.sprites.get(&collider_lines.sprite_label) {
+                *transform = sprite.bevy_transform();
+                // We want collider lines to appear on top of the sprite they are for, so they need a
+                // slightly higher z value. We tell users to only use up to 999.0.
+                transform.translation.z = (transform.translation.z + 0.1).clamp(0.0, 999.1);
+            }
+            // Stroke line width gets scaled with the transform, but we want it to appear to be the same
+            // regardless of scale, so we have to counter the scale.
+            if let DrawMode::Stroke(ref mut stroke_mode) = *draw_mode {
+                let line_width = 1.0 / transform.scale.x;
+                *stroke_mode = StrokeMode::new(Color::WHITE, line_width);
+            }
+        }
+    }
+    engine_state.last_show_colliders = engine_state.show_colliders;
+
     // Transfer any changes in the user's Sprite copies to the Bevy Sprite and Transform components
-    for (entity, mut sprite, mut transform) in query_set.q2_mut().iter_mut() {
+    for (entity, mut sprite, mut transform) in query_set.q0().iter_mut() {
         if let Some(sprite_copy) = engine_state.sprites.remove(&sprite.label) {
             *sprite = sprite_copy;
             *transform = sprite.bevy_transform();
@@ -488,8 +478,11 @@ fn game_logic_sync(
         }
     }
 
+    // Add Bevy components for any new sprites remaining in engine_state.sprites
+    add_sprites(&mut commands, &asset_server, &mut engine_state);
+
     // Transfer any changes in the user's Texts to the Bevy Text and Transform components
-    for (entity, mut text, mut transform, mut bevy_text_component) in query_set.q3_mut().iter_mut() {
+    for (entity, mut text, mut transform, mut bevy_text_component) in query_set.q1().iter_mut() {
         if let Some(text_copy) = engine_state.texts.remove(&text.label) {
             *text = text_copy;
             *transform = text.bevy_transform();
@@ -510,21 +503,17 @@ fn game_logic_sync(
         }
     }
 
-    // Add Bevy components for any new sprites remaining in engine_state.sprites
-    rusty_engine::game::add_sprites(&mut commands, &asset_server, materials, &mut engine_state);
-
     // Add Bevy components for any new texts remaining in engine_state.texts
-    rusty_engine::game::add_texts(&mut commands, &asset_server, &mut engine_state);
+    add_texts(&mut commands, &asset_server, &mut engine_state);
 
     if engine_state.should_exit {
         app_exit_events.send(AppExit);
     }
 }
 
-
 // The Deref and DerefMut implementations make it so that you can call all the `EngineState` methods
 // on a `Game`, which is much more straightforward for game setup in `main()`
-impl Deref for Game {
+impl<S: Send + Sync + 'static> Deref for Game<S> {
     type Target = EngineState;
 
     fn deref(&self) -> &Self::Target {
@@ -532,11 +521,8 @@ impl Deref for Game {
     }
 }
 
-impl DerefMut for Game {
+impl<S: Send + Sync + 'static> DerefMut for Game<S> {
     fn deref_mut(&mut self) -> &mut Self::Target {
         &mut self.engine_state
     }
 }
-
-};
-}
